==> CloudClientStandardAWS_v2.0.0.zip: com.clustercontrol.cloud.base_2.0.0/com/clustercontrol/cloud/presenter/ModifyCloudUserRequest.java <==
package com.clustercontrol.cloud.presenter;

import com.clustercontrol.cloud.commons.util.annotation.Export;
import com.clustercontrol.cloud.commons.util.annotation.Import;

public class ModifyCloudUserRequest {
	private String cloudUserId;
	private String cloudUserName;
	private String description;
	private String accountResourceId;
	private String cloudUserType;
	private String accessKey;
	private String secretKey;
	private String roleId;

	@Export
	public String getCloudUserId() {
		return cloudUserId;
	}

	@Export
	public String getCloudUserName() {
		return cloudUserName;
	}

	@Export
	public String getDescription() {
		return description;
	}

	@Export
	public String getAccountResourceId() {
		return accountResourceId;
	}

	@Export
	public String getCloudUserType() {
		return cloudUserType;
	}

	@Export
	public String getAccessKey() {
		return accessKey;
	}

	@Export
	public String getSecretKey() {
		return secretKey;
	}

	@Export
	public String getRoleId() {
		return roleId;
	}

	@Import
	public void setCloudUserId(String cloudUserId) {
		this.cloudUserId = cloudUserId;
	}

	@Import
	public void setCloudUserName(String cloudUserName) {
		this.cloudUserName = cloudUserName;
	}

	@Import
	public void setDescription(String description) {
		this.description = description;
	}

	@Import
	public void setAccountResourceId(String accountResourceId) {
		this.accountResourceId = accountResourceId;
	}

	@Import
	public void setCloudUserType(String cloudUserType) {
		this.cloudUserType = cloudUserType;
	}

	@Import
	public void setAccessKey(String accessKey) {
		this.accessKey = accessKey;
	}

	@Import
	public void setSecretKey(String secretKey) {
		this.secretKey = secretKey;
	}

	@Import
	public void setRoleId(String roleId) {
		this.roleId = roleId;
	}
}

==> CloudClientStandardAWS_v2.0.3.zip: com.clustercontrol.cloud.base_2.0.3/com/clustercontrol/cloud/presenter/ModifyCloudUserRequest.java <==
/*
Copyright (C) 2013 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.
 */
package com.clustercontrol.cloud.presenter;

import com.clustercontrol.cloud.commons.util.annotation.Export;
import com.clustercontrol.cloud.commons.util.annotation.Import;

public class ModifyCloudUserRequest {
	private String cloudUserId;
	private String cloudUserName;
	private String description;
	private String accountResourceId;
	private String cloudUserType;
	private String accessKey;
	private String secretKey;
	private String roleId;

	@Export
	public String getCloudUserId() {
		return cloudUserId;
	}

	@Export
	public String getCloudUserName() {
		return cloudUserName;
	}

	@Export
	public String getDescription() {
		return description;
	}

	@Export
	public String getAccountResourceId() {
		return accountResourceId;
	}

	@Export
	public String getCloudUserType() {
		return cloudUserType;
	}

	@Export
	public String getAccessKey() {
		return accessKey;
	}

	@Export
	public String getSecretKey() {
		return secretKey;
	}

	@Export
	public String getRoleId() {
		return roleId;
	}

	@Import
	public void setCloudUserId(String cloudUserId) {
		this.cloudUserId = cloudUserId;
	}

	@Import
	public void setCloudUserName(String cloudUserName) {
		this.cloudUserName = cloudUserName;
	}

	@Import
	public void setDescription(String description) {
		this.description = description;
	}

	@Import
	public void setAccountResourceId(String accountResourceId) {
		this.accountResourceId = accountResourceId;
	}

	@Import
	public void setCloudUserType(String cloudUserType) {
		this.cloudUserType = cloudUserType;
	}

	@Import
	public void setAccessKey(String accessKey) {
		this.accessKey = accessKey;
	}

	@Import
	public void setSecretKey(String secretKey) {
		this.secretKey = secretKey;
	}

	@Import
	public void setRoleId(String roleId) {
		this.roleId = roleId;
	}
}
